checkcolnames: checkcolnames
Description
Check the column names of different tabs in the dataset to make sure they match, used in dataQC
Usage
checkcolnames(data, tab, soilcarbon_template)
Arguments
tab
specific tab of dataset , ie. dataset_name
soilcarbon_template
template soilcarbon file to compare