Learn R Programming

soilcarbon (version 1.2.0)

checknames: checknames

Description

Check the names of different levels in the dataset to make sure they match, used in dataQC

Usage

checknames(data, name, tabs)

Arguments

data

soilcarbon data

name

specific heirarchial name, ie. dataset_name

tabs

the tabs that will be checked, default is all